@@ -1,13 +1,13 @@
-/* 
+/*
  *  IMS Open Corpus Workbench (CWB)
  *  Copyright (C) 1993-2006 by IMS, University of Stuttgart
  *  Copyright (C) 2007-     by the respective contributers (see file AUTHORS)
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
  *  Free Software Foundation; either version 2, or (at your option) any later
  *  version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
@@ -15,18 +15,15 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
-#ifndef _COMPRESSION_H_
-#define _COMPRESSION_H_
-
-#include "globals.h"
+#ifndef _cl_compression_h_
+#define _cl_compression_h_
 
+//#include "globals.h"
 #include "bitio.h"
 
 int compute_ba(int ft, int corpus_size);
-
 int read_golomb_code_bs(int b, BStream *bs);
 int read_golomb_code_bf(int b, BFile *bf);
-
 int write_golomb_code(int x, int b, BFile *bf);
 
 #endif
